@@ -116,7 +116,13 @@ solnp = function(pars, fun, eqfun = NULL, eqB = NULL, ineqfun = NULL, ineqLB = N
 		ind[4] 	= 1
 		nineq 	= length(ineqLB)
 		ind[5] 	= nineq
-		ineqx0 	= (.ineqLB + .ineqUB)/2
+		
+		# check for infinities/nans
+		.ineqLBx = .ineqLB
+		.ineqUBx = .ineqUB
+		.ineqLBx[!is.finite(.ineqLB)] = -1e10
+		.ineqUBx[!is.finite(.ineqUB)] =  1e10
+		ineqx0 	= (.ineqLBx + .ineqUBx)/2
 		#if(!is.null(ineqgrad)){
 		#	ineqjacv = .cheqjacineq(pars, gradineq, .ineqUB, .ineqLB, .solnpenv, ...)
 		#	ind[6] = 1
@@ -245,7 +251,7 @@ solnp = function(pars, fun, eqfun = NULL, eqB = NULL, ineqfun = NULL, ineqLB = N
 				ctrl = .subnp_ctrl, .env = .solnpenv, ...)
 		if(get(".solnp_errors", envir =  .solnpenv) == 1){
 			maxit = .solnp_iter
-		}		
+		}
 		p  = res$p
 		lambda  = res$y
 		hessv  = res$hessv
@@ -340,4 +346,4 @@ solnp = function(pars, fun, eqfun = NULL, eqB = NULL, ineqfun = NULL, ineqLB = N
 			hessian = hessv, ineqx0 = ineqx0, nfuneval = ctmp, outer.iter = .solnp_iter, 
 			elapsed = toc)
 	return( ans )
-}
\ No newline at end of file
+}
