@@ -14,9 +14,8 @@
 ##   GNU General Public License for more details.
 ##
 #################################################################################
-.onLoad = function(libname, pkgname)
-{
-        version <- utils::packageDescription("Rsolnp")$Version
-	writeLines(sprintf("%s (version %s) initialized.", pkgname, version))
-}
-
+.onLoad <- function(lib, pkg) {
+	if(interactive() || getOption("verbose")){
+		packageStartupMessage(sprintf("Package %s (%s) loaded.  To cite, see citation(\"%s\")\n",pkg, utils::packageDescription(pkg)$Version, pkg))
+	}
+}
\ No newline at end of file
